@@ -37,6 +37,22 @@
 #include "panel-scaler-private.h"
 #include "panel-widget-private.h"
 
+#define REMOVED_SHORTCUTS \
+  (ADW_TAB_VIEW_SHORTCUT_CONTROL_HOME \
+  | ADW_TAB_VIEW_SHORTCUT_CONTROL_SHIFT_HOME \
+  | ADW_TAB_VIEW_SHORTCUT_CONTROL_END \
+  | ADW_TAB_VIEW_SHORTCUT_CONTROL_SHIFT_END)
+
+/**
+ * PanelFrame:
+ *
+ * The #PanelFrame is a widget containing panels to display in an
+ * area. The widgets are added internally in an [class@Adw.TabView] to
+ * display them one at a time like in a stack.
+ *
+ * A #PanelFrame can also have a header widget that will be displayed
+ * above the panels.
+ */
 typedef struct
 {
   PanelFrameHeader  *header;
@@ -85,6 +101,12 @@ static guint signals [N_SIGNALS];
 static GParamSpec *properties [N_PROPS];
 static GtkBuildableIface *parent_buildable;
 
+/**
+ * panel_frame_new:
+ * Create a new #PanelFrame.
+ *
+ * Returns: a newly created #PanelFrame object.
+ */
 GtkWidget *
 panel_frame_new (void)
 {
@@ -1005,6 +1027,8 @@ panel_frame_init (PanelFrame *self)
 
   gtk_widget_init_template (GTK_WIDGET (self));
 
+  adw_tab_view_remove_shortcuts (priv->tab_view, REMOVED_SHORTCUTS);
+
   _panel_dock_update_orientation (GTK_WIDGET (self),
                                   gtk_orientable_get_orientation (GTK_ORIENTABLE (self)));
 
@@ -1057,6 +1081,14 @@ modified_to_indicator_icon (GBinding     *binding,
   return TRUE;
 }
 
+/**
+ * panel_frame_add_before:
+ * @self: a #PanelFrame
+ * @panel: (transfer none): the #PanelWidget to add.
+ * @sibling: (transfer none): the sibling #PanelWidget to add the panel before.
+ *
+ * Add @panel before @sibling in the #PanelFrame.
+ */
 void
 panel_frame_add_before (PanelFrame  *self,
                         PanelWidget *panel,
@@ -1136,7 +1168,7 @@ panel_frame_add_before (PanelFrame  *self,
 /**
  * panel_frame_add:
  * @self: a #PanelFrame
- * @panel: a widget to add
+ * @panel: a #PanelWidget to add
  *
  * Adds a widget to the frame.
  */
@@ -1150,7 +1182,7 @@ panel_frame_add (PanelFrame  *self,
 /**
  * panel_frame_remove:
  * @self: a #PanelFrame
- * @panel: a widget to add
+ * @panel: a #PanelWidget to remove.
  *
  * Removes a widget from the frame.
  */
@@ -1195,6 +1227,14 @@ panel_frame_remove (PanelFrame  *self,
   panel_frame_update_actions (self);
 }
 
+/**
+ * panel_frame_get_empty:
+ * @self: a #PanelFrame
+ *
+ * Tells if the panel frame is empty.
+ *
+ * Returns: %TRUE if the panel is empty.
+ */
 gboolean
 panel_frame_get_empty (PanelFrame *self)
 {
@@ -1406,6 +1446,14 @@ _panel_frame_transfer (PanelFrame  *self,
     _panel_grid_update_focus (PANEL_GRID (grid));
 }
 
+/**
+ * panel_frame_get_n_pages:
+ * @self: a #PanelFrame
+ *
+ * Gets the number of pages in the panel frame.
+ *
+ * Returns: The number of pages.
+ */
 guint
 panel_frame_get_n_pages (PanelFrame *self)
 {
@@ -1584,6 +1632,14 @@ _panel_frame_request_close (PanelFrame  *self,
     adw_tab_view_close_page (priv->tab_view, page);
 }
 
+/**
+ * panel_frame_get_closeable:
+ * @self: a #PanelFrame
+ *
+ * Tells if the panel frame is closeable.
+ *
+ * Returns: %TRUE if the panel frame is closeable.
+ */
 gboolean
 panel_frame_get_closeable (PanelFrame *self)
 {
@@ -1649,6 +1705,14 @@ panel_frame_get_position (PanelFrame *self)
   return g_steal_pointer (&position);
 }
 
+/**
+ * panel_frame_get_requested_size:
+ * @self: a %PanelFrame
+ *
+ * Gets the requested size for the panel frame.
+ *
+ * Returns: the requested size.
+ */
 int
 panel_frame_get_requested_size (PanelFrame *self)
 {
@@ -1662,6 +1726,13 @@ panel_frame_get_requested_size (PanelFrame *self)
   return panel_resizer_get_drag_position (PANEL_RESIZER (resizer));
 }
 
+/**
+ * panel_frame_set_requested_size:
+ * @self: a %PanelFrame.
+ * @requested_size: the requested size.
+ *
+ * Sets the requested size for the panel frame.
+ */
 void
 panel_frame_set_requested_size (PanelFrame *self,
                                 int         requested_size)
